/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package productcatalog.db;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 *
 * @author petr
 */
public abstract class DBTools {

    private static Logger logger = Logger.getLogger(DBTools.class.getName());

    // this methods throws unchecked exception because using nonexisting
    // resource name is programmer fault
    private static String loadSQL(String filename) {
        try {
            InputStream is = DBTools.class.getResourceAsStream(filename);
            if (is == null) {
                throw new IllegalArgumentException(filename + " not found");
            }
            InputStreamReader reader = new InputStreamReader(is, "utf-8");
            char[] buffer = new char[1024];
            StringBuilder result = new StringBuilder();
            while (true) {
                int count = reader.read(buffer);
                if (count < 0) {
                    break;
                }
                result.append(buffer, 0, count);
            }
            return result.toString();
        } catch (IOException ex) {
            throw new RuntimeException("Error when loading " + filename, ex);
        }
    }

    public static void closeQuietly(Statement st) {
        if (st != null) {
            try {
                st.close();
            } catch (SQLException ex) {
                logger.log(Level.SEVERE, "Exception thrown when closing statement", ex);
            }
        }
    }

    public static void closeQuietly(Connection conn) {
        if (conn != null) {
            try {
                conn.close();
            } catch (SQLException ex) {
                logger.log(Level.SEVERE, "Exception thrown when closing connection", ex);
            }
        }
    }
}
